@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0103';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -118,7 +118,7 @@ sub _build__database {
             for my $pitch (@pitches) {
                 my $chord = $self->_modes->{$mode}[$i]{chord};
                 my $function = $self->_modes->{$mode}[$i]{function};
-                $database .= "chord_key($mode_base, $mode, $pitch, $chord, $function).\n";
+                $database .= "chord_key($pitch, $chord, $mode_base, $mode, $function).\n";
                 $i++;
             }
         }
@@ -127,9 +127,9 @@ sub _build__database {
 % Can a chord in one key function in a second?
 pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key2Note, Key2, Key2Function) :-
     % bind the chord to the function of the first key
-    chord_key(Key1Note, Key1, ChordNote, Chord, Key1Function),
+    chord_key(ChordNote, Chord, Key1Note, Key1, Key1Function),
     % bind the chord to the function of the second key
-    chord_key(Key2Note, Key2, ChordNote, Chord, Key2Function),
+    chord_key(ChordNote, Chord, Key2Note, Key2, Key2Function),
     % the functions cannot be the same
     Key1Function \= Key2Function.
 RULE
@@ -142,10 +142,10 @@ sub chord_key {
     my ($self) = @_;
     my $prolog = AI::Prolog->new($self->_database);
     my $query = sprintf 'chord_key(%s, %s, %s, %s, %s).',
-        defined $self->mode_note    ? $self->mode_note    : 'ModeNote',
-        defined $self->mode         ? $self->mode         : 'Mode',
         defined $self->chord_note   ? $self->chord_note   : 'ChordNote',
         defined $self->chord        ? $self->chord        : 'Chord',
+        defined $self->key_note     ? $self->key_note     : 'KeyNote',
+        defined $self->key          ? $self->key          : 'Key',
         defined $self->key_function ? $self->key_function : 'KeyFunction',
     ;
     $prolog->query($query);
@@ -192,7 +192,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0103
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -205,8 +205,8 @@ version 0.0103
     key_function => 'dominant',
   );
   my $q = $m->chord_key;
-  # [['chord_key','g','ionian','d','maj','dominant'],
-  #  ['chord_key','g','lydian','d','maj','dominant']]
+  # [['chord_key','d','maj','g','ionian','dominant'],
+  #  ['chord_key','d','maj','g','lydian','dominant']]
 
   # In what key(s) can a Gmaj chord function as a subdominant pivot chord?
   $m = Music::ModalFunction->new(
@@ -268,7 +268,7 @@ Ask the database a question about what chords are in what keys.
 
 Arguments:
 
-  chord_key(ModeNote, Mode, ChordNote, Chord, KeyFunction)
+  chord_key(ChordNote, Chord, KeyNote, Key, KeyFunction)
 
 If defined, the argument in that position will be bound to that value
 (e.g. C<'_'> even). Otherwise an unbound variable is used.
